"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QuestionRecord = void 0;
const uuid_1 = require("uuid");
const handleError_1 = require("../utils/handleError");
const db_1 = require("../utils/db");
const questionAndAnswer_record_1 = require("./supportRecord/questionAndAnswer.record");
const modules_record_1 = require("./modules.record");
class QuestionRecord {
    constructor(obj) {
        if (obj.question.length === 0) {
            throw new handleError_1.ValidationError('Nie podano treści pytania.');
        }
        if (obj.correctAnswer.length === 0) {
            throw new handleError_1.ValidationError('Nie wprowadzono poprawnej odpowiedzi.');
        }
        if (obj.module.length === 0 || obj.module === 'Wybierz') {
            throw new handleError_1.ValidationError('Brak przyporządkowania pytania do przedmiotu.');
        }
        this.module = obj.module.charAt(0).toUpperCase() + obj.module.slice(1).toLowerCase();
        this.id = obj.id;
        this.question = obj.question;
        this.correctAnswer = obj.correctAnswer;
        this.badAnswer1 = obj.badAnswer1;
        this.badAnswer2 = obj.badAnswer2;
        this.badAnswer3 = obj.badAnswer3;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            let isNewModule = false;
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already inserted.');
            }
            const moduleArray = yield modules_record_1.ModuleRecord.getAllModules();
            if (!moduleArray.find(el => el.module === this.module)) {
                isNewModule = true;
                yield modules_record_1.ModuleRecord.addModule(this.module);
            }
            yield db_1.pool.execute('INSERT INTO `questions` VALUES(:id, :question, :correctAnswer, :badAnswer1, :badAnswer2, :badAnswer3, :module)', {
                id: this.id,
                question: this.question,
                correctAnswer: this.correctAnswer,
                badAnswer1: this.badAnswer1,
                badAnswer2: this.badAnswer2,
                badAnswer3: this.badAnswer3,
                module: this.module,
            });
            return isNewModule;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('UPDATE `questions` SET `question` = :question, `correctAnswer` = :correctAnswer, `badAnswer1` = :badAnswer1, `badAnswer2` = :badAnswer2, `badAnswer3` = :badAnswer3, `module` = :module  WHERE `id` = :id', {
                id: this.id,
                question: this.question,
                correctAnswer: this.correctAnswer,
                badAnswer1: this.badAnswer1,
                badAnswer2: this.badAnswer2,
                badAnswer3: this.badAnswer3,
                module: this.module,
            });
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `questions` WHERE `id` = :id', {
                id: this.id,
            });
        });
    }
    static getQuestionAndAnswer() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT `question`, `correctAnswer`, `module`, `id` FROM `questions`');
            return results.length === 0 ? null : results.map(q => new questionAndAnswer_record_1.QuestionAndAnswerRecord({
                id: q.id,
                module: q.module,
                question: q.question,
                answer: q.correctAnswer,
            }));
        });
    }
    static getQuestionAndAnswerFromModule(module) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT `question`, `correctAnswer`, `module`, `id` FROM `questions` WHERE `module` = :module', {
                module,
            });
            return results.length === 0 ? null : results.map(q => new questionAndAnswer_record_1.QuestionAndAnswerRecord({
                id: q.id,
                module: q.module,
                question: q.question,
                answer: q.correctAnswer,
            }));
        });
    }
    static search(content) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `questions` where `question` LIKE :content OR `correctAnswer` LIKE :content ', {
                content: `%${content}%`,
            });
            return results;
        });
    }
    static searchAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `questions`');
            return results;
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `questions` WHERE `id` = :id', {
                id,
            });
            return results.length === 0 ? null : new QuestionRecord(results[0]);
        });
    }
}
exports.QuestionRecord = QuestionRecord;
//# sourceMappingURL=question.record.js.map