"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
const questionResponse_record_1 = require("./supportRecord/questionResponse.record");
const modules_record_1 = require("./modules.record");
const shuffleAnswers_1 = require("../utils/shuffleAnswers");
class TestRecord {
    static createGeneralTest() {
        return __awaiter(this, void 0, void 0, function* () {
            const modules = yield modules_record_1.ModuleRecord.getAllModules();
            const questionsList = [];
            for (const module of modules) {
                const [results] = yield db_1.pool.execute('SELECT * FROM `questions` WHERE `module` = :module AND `badAnswer1` IS NOT NUll ORDER BY RAND() LIMIT 5', {
                    module: module.module
                });
                results.map(question => new questionResponse_record_1.TestQuestionRecord({
                    id: question.id,
                    question: question.question,
                    answers: [
                        {
                            id: (0, uuid_1.v4)(),
                            answer: question.correctAnswer,
                            points: 1,
                        },
                        {
                            id: (0, uuid_1.v4)(),
                            answer: question.badAnswer1,
                            points: 0,
                        },
                        {
                            id: (0, uuid_1.v4)(),
                            answer: question.badAnswer2,
                            points: 0,
                        },
                        {
                            id: (0, uuid_1.v4)(),
                            answer: question.badAnswer3,
                            points: 0,
                        }
                    ],
                }))
                    .forEach(obj => questionsList.push(obj));
            }
            questionsList.map(questions => (0, shuffleAnswers_1.shuffleAnswers)(questions.answers));
            return questionsList;
        });
    }
    static createModuleTest(module, questionsCount) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `questions` WHERE `module` = :module AND `badAnswer1` IS NOT NUll ORDER BY RAND() LIMIT :questionsCount', {
                module,
                questionsCount
            });
            const questionsList = [];
            results.map(question => new questionResponse_record_1.TestQuestionRecord({
                id: question.id,
                question: question.question,
                answers: [
                    {
                        id: (0, uuid_1.v4)(),
                        answer: question.correctAnswer,
                        points: 1,
                    },
                    {
                        id: (0, uuid_1.v4)(),
                        answer: question.badAnswer1,
                        points: 0,
                    },
                    {
                        id: (0, uuid_1.v4)(),
                        answer: question.badAnswer2,
                        points: 0,
                    },
                    {
                        id: (0, uuid_1.v4)(),
                        answer: question.badAnswer3,
                        points: 0,
                    }
                ],
            }))
                .forEach(obj => questionsList.push(obj));
            questionsList.map(questions => (0, shuffleAnswers_1.shuffleAnswers)(questions.answers));
            return questionsList;
        });
    }
}
exports.TestRecord = TestRecord;
//# sourceMappingURL=test.record.js.map