"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const hash_pwd_1 = require("../utils/hash-pwd");
const db_1 = require("../utils/db");
const handleError_1 = require("../utils/handleError");
const uuid_1 = require("uuid");
class UserRecord {
    constructor(obj) {
        this.login = obj.login;
        this.pwdHash = (0, hash_pwd_1.hashPwd)(obj.password);
    }
    register() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            const [result] = yield db_1.pool.execute('SELECT * FROM `users` WHERE `login` = :login', {
                login: this.login
            });
            if (result.length !== 0) {
                throw new handleError_1.ValidationError('Podana nazwa użytkownika jest juz zajęta');
            }
            else {
                yield db_1.pool.execute('INSERT INTO `users` VALUES(:id, :login, :pwdHash)', {
                    id: this.id,
                    login: this.login,
                    pwdHash: this.pwdHash,
                });
                return true;
            }
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `users` WHERE `id` = :id', {
                id,
            });
            return results.length === 0 ? null : results[0];
        });
    }
    static search(content) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT `id`, `login` FROM `users` WHERE `login` LIKE :content', {
                content: `%${content}%`,
            });
            return results;
        });
    }
    static searchAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT `id`, `login` FROM `users`');
            return results;
        });
    }
    static delete(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `users` WHERE `id` = :id', {
                id
            });
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map